@@ -56,7 +56,7 @@ void EmptyTrashCommand::execute()
             return;
         }
         Akonadi::Collection trash = trashCollectionFolder();
-        QVector<Akonadi::Collection> trashFolder;
+        QList<Akonadi::Collection> trashFolder;
         trashFolder << trash;
 
         const Akonadi::AgentInstance::List lst = agentInstances();
@@ -162,3 +162,5 @@ void EmptyTrashCommand::emitResult(Result value)
         deleteLater();
     }
 }
+
+#include "moc_emptytrashcommand.cpp"
